# BLEACH: Krowned Kueens Digital Audio Workstation

## Technical Documentation

### Architecture

The application is built using Python with PyQt5 for the user interface and OpenGL for 3D rendering. The main components are:

1. **User Interface**: Implemented using PyQt5, provides the main window, menus, and buttons
2. **3D Rendering**: Uses OpenGL through PyQt5's QGLWidget to render Yoruichi and the drumset
3. **Animation System**: Handles animations for Yoruichi and the drumset components
4. **Model Loading**: Loads the rigged Blender models and converts them for OpenGL rendering

### Dependencies

- Python 3.8 or later
- PyQt5 5.15.0 or later
- PyOpenGL 3.1.0 or later
- NumPy 1.19.0 or later
- Blender 3.0 or later (for model rigging and export)

### File Structure

- **main.py**: Main application entry point
- **models/**: Directory containing the rigged Blender models
  - **YoruichiPhase1_Rigged.blend**: Rigged Yoruichi character model
  - **Drumset_Rigged.blend**: Rigged drumset model
- **documentation/**: User and technical documentation

### Development

To modify or extend the application, you'll need to understand the following classes:

- **KrownedKueensDAW**: Main application window class
- **ModelRenderer**: OpenGL renderer for 3D models
- **BlenderModelLoader**: Utility class for loading Blender models

### Building

To build standalone executables for different platforms:

- **Windows**: Use PyInstaller or cx_Freeze
- **macOS**: Use py2app
- **Linux**: Use PyInstaller or cx_Freeze
